==> haskell-network-udp-0.0.0-126-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-network-udp.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 network-udp
version:              0.0.0
visibility:           public
id:                   network-udp-0.0.0-8Ka4HYKpw77Cv9EblwcaG8
key:                  network-udp-0.0.0-8Ka4HYKpw77Cv9EblwcaG8
license:              BSD-3-Clause
maintainer:           kazu@iij.ad.jp
author:               Kazu Yamamoto
synopsis:             UDP library
description:          Best current practice library for UDP clients and servers.
category:             Network
abi:                  a08459a8dc945cf8385e00296a88f636
exposed:              True
exposed-modules:      Network.UDP
hidden-modules:       Network.UDP.Recv Network.UDP.Types
import-dirs:          /usr/lib/ghc-9.4.8/site-local/network-udp-0.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/network-udp-0.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/network-udp-0.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-network-udp
hs-libraries:         HSnetwork-udp-0.0.0-8Ka4HYKpw77Cv9EblwcaG8
depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    iproute-1.7.15-AOqG5DOPTftA8D6MhRD5U4
    network-3.1.4.0-Ez30o8Wyt6m7hXZSCgqaWo

haddock-interfaces:   /usr/share/doc/haskell-network-udp/html/network-udp.haddock
haddock-html:         /usr/share/doc/haskell-network-udp/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-network-udp-0.0.0-127-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-network-udp.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 network-udp
version:              0.0.0
visibility:           public
id:                   network-udp-0.0.0-7pmnuZ4LLu6EYFdgQxlmAY
key:                  network-udp-0.0.0-7pmnuZ4LLu6EYFdgQxlmAY
license:              BSD-3-Clause
maintainer:           kazu@iij.ad.jp
author:               Kazu Yamamoto
synopsis:             UDP library
description:          Best current practice library for UDP clients and servers.
category:             Network
abi:                  21bafe9991fbca52e6b60752cad4ea1e
exposed:              True
exposed-modules:      Network.UDP
hidden-modules:       Network.UDP.Recv Network.UDP.Types
import-dirs:          /usr/lib/ghc-9.4.8/site-local/network-udp-0.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/network-udp-0.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/network-udp-0.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-network-udp
hs-libraries:         HSnetwork-udp-0.0.0-7pmnuZ4LLu6EYFdgQxlmAY
depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    iproute-1.7.15-73DyVtyRAHvBXQy5CvTjcr
    network-3.1.4.0-5tdSDQBC1SF9do6vOgsoy3

haddock-interfaces:   /usr/share/doc/haskell-network-udp/html/network-udp.haddock
haddock-html:         /usr/share/doc/haskell-network-udp/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
